@@ -10,7 +10,12 @@ def get_keywords(file_path, max_ngram_size=3, deduplication_threshold=0.9, numOf
         # create a PDF reader object
         pdf_reader = PyPDF2.PdfReader(pdf_file)
         # get the number of pages
-        num_pages = pdf_reader.numPages
+
+        # Removed from 0.2.1
+        # #num_pages = pdf_reader.numPages
+        # Added in 0.2.2
+        num_pages = len(pdf_reader.pages)
+
         # initialize the text variable
         text = ""
         # loop through each page and extract the text
